@@ -2,7 +2,7 @@
 import subprocess, time
 import py
 import pytest
-from devpi.server import ensure_autoserver, AutoServer, default_rooturl, main
+from devpi.server import handle_autoserver, AutoServer, default_rooturl, main
 from requests.exceptions import ConnectionError
 
 @pytest.fixture
@@ -24,14 +24,14 @@ def mockpopen(monkeypatch):
 @pytest.mark.parametrize("raising", [True, False])
 @pytest.mark.parametrize("rooturl", ["/", default_rooturl])
 @pytest.mark.parametrize("logfile", [None, "line1\nline2\nline3\n"])
-def test_ensure_autoserver(loghub, tmpdir, monkeypatch, raising, rooturl,
+def test_handle_autoserver(loghub, tmpdir, monkeypatch, raising, rooturl,
                            mockpopen, logfile):
     l = []
     class current:
         simpleindex = None
         @classmethod
         def configure_fromurl(cls, hub, url):
-            assert url == default_rooturl + "root/dev/"
+            assert url == default_rooturl + "/root/dev/"
             l.append(1)
     current.rooturl = rooturl
 
@@ -51,23 +51,23 @@ def test_ensure_autoserver(loghub, tmpdir, monkeypatch, raising, rooturl,
     monkeypatch.setattr(loghub.http, "get", get)
     monkeypatch.delenv("DEVPI_NO_AUTOSERVER")
     if raising:
-        ensure_autoserver(loghub, current)
+        handle_autoserver(loghub, current)
         assert l == [1]
         assert len(g) == 1
     else:
-        ensure_autoserver(loghub, current)
-        assert not l
+        handle_autoserver(loghub, current)
+        assert l == [1]
         autoserver = AutoServer(loghub)
         if logfile:
             autoserver.info.logpath.ensure()
             autoserver.info.logpath.write(logfile)
         autoserver.log()
 
-def test_ensure_autoserver_does_nothing_with_non_default(loghub):
+def test_handle_autoserver_does_nothing_with_non_default(loghub):
     class current:
         rooturl = "http://localhost:3142/"
     loghub.http = None
-    ensure_autoserver(loghub, current)
+    handle_autoserver(loghub, current)
 
 def test_log(loghub):
     autoserver = AutoServer(loghub)
